#
# spec file for package nootka
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           nootka
Version:        1.4.5
Release:        lp150.1.1
Summary:        Application to help with learning classical score notation
License:        GPL-3.0
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://nootka.sf.net
Source0:        https://sourceforge.net/projects/nootka/files/Nootka-%{version}/nootka-%{version}-source.tar.bz2

BuildRequires:  cmake
BuildRequires:  desktop-file-utils 
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(vorbis)

%description
Nootka is an application to learn classical score notation.
It helps to understand the rules of reading and writing scores
and helps with developing skills of playing and singing notes.

Features:
numerous settings to personalize for user needs and capabilities
natural sound of classical guitar
accurate pitch detection method
support for different name-callings of the notes
exams with different levels
levels creator with wide range of settings


%prep
%setup -q -n %{name}-%{version}-source


%build
cmake -DOBS_SUSE_QUIRKS=ON \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} .
make %{?_smp_mflags}


%install
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}/%{_datadir}/doc/%{name}
%suse_update_desktop_file -r %{name} Education Music


%post
/usr/bin/update-desktop-database &> /dev/null || :
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :


%postun
/usr/bin/update-desktop-database &> /dev/null || :
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :


%files
%defattr(-,root,root,-)
%doc copyright
%{_bindir}/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_datadir}/applications/*
%{_datadir}/man/man1/*
%{_datadir}/mime/packages/*
%{_datadir}/pixmaps/*
%dir /usr/lib/%{name}
/usr/lib/%{name}/*


%changelog
* Sun Apr 22 2018 ecsos@opensuse.org
- update to 1.4.5
  - added Hungarian translations
  - Stylus support on touch screens (Requires Qt 5.9)
  - using secure SSL connections when possible (update check,links)
  BUGS FIXES
  - Don't stop pitch detection when question and answer are a sound
* Mon Sep 11 2017 ecsos@opensuse.org
- update to 1.4.4
  - German translation is complete
  - support for marking more frets on the fingerboard
  BUGS FIXES
  - fixed annoying crash on entering settings when 'other'
    instrument was used
- drop patch nootka-moc-fix.patch because now in upstream
* Wed Jul 12 2017 ecsos@opensuse.org
- add patch nootka-moc-fix.patch to build for Factory
* Mon Jun 12 2017 ecsos@opensuse.org
- update to 1.4.3
  ANDROID
  - attempt to fix random crashes related to audio input
  Mac
  - improved look of checkable buttons (note name)
  BUGS FIXES
  - removed a few memory leaks
* Fri Feb 24 2017 ecsos@opensuse.org
- update to 1.4.2
  - added standalone AppImage for Linux
  BUGS FIXES
  - don't stop pitch detection after playing a note
  - avoid false update messages
  - properly detect default language under Win 10
* Fri Jan 20 2017 ecsos@opensuse.org
- update to 1.4.1
  BUGS FIXES
  - Fixed issues with note range in custom created levels
* Wed Dec 14 2016 ecsos@opensuse.org
- update to 1.4.0
  - new method to make random melodies more... melodic
  - melody can be randomized from selected notes, i.e. pentatonic scale
  - so added level with pentatonic scales
  - solfege or letter note names can be selected during first run wizard
  - improved look of sound views, better fit to high DPI screens
  ANDROID
  - reduced number of paint operations, works even 2-4 times faster
  - volume settings and pitch preview can be invoked with volume keys
  - settings menu entry is placed on the top menu label
  - stop pitch detection when app is going background, restore when backs
  BUGS FIXES
  - fixed positioning of tips with question content
  - other small fixes
- changes from 1.3.0 alpha1
  - removed roundness of widget/tips
  - scroll-able widgets can be flicked with mouse/finger
  - improved scaling of dialog windows
  - prepared code for further features
  Under the hood
  - Android and Desktop code are in the single branch now
  - reorganized layout of libraries, score is in separate lib
  - exam execution moved to plugin
- changes from 1.2A.7 rc3
  ANDROID
  - handle pinch gesture to zoom score in/out
  - touching screen suspends pitch detection
  - updated Qt version to 5.6.1
  BUGS FIXES
  - prevent stopping input sound randomly
  - fixed issues with saving exams/levels on device
* Mon Aug 29 2016 ecsos@opensuse.org
- update to 1.2.7
  - translated to Spanish language
  - better method of handling input audio data, increased buffer size
  - forwarding input to output works with every sound system now
  BUGS FIXES
  - fixed reason of random crashes when audio input started
  - repaired starting exam with melodies from single note mode view
  - file descriptions are translated under Mac Os Finder
  - fixed deb package compatibility with Ubuntu 16.04
  - other minor fixes
* Mon Jun 13 2016 ecsos@opensuse.org
- update to 1.2.6
  - clicking melody note displays guitar position (only exercises)
  - updated Russian translation
  - improvements of scaling guitar image for different resolutions
  BUGS FIXES
  - fixed bug with doubled fingerboard on high resolution screens
  - keep right-side note pane always visible, even at the staff end
* Fri Apr 15 2016 ecsos@opensuse.org
- update to 1.2.5
  - added new levels
  - added donors list
  BUGS FIXES
  - clef menu visibility fixes for Qt 5.6 compatibility
  - fixed storing of instrument scale for non guitars
  - other minor fixes
* Wed Feb  3 2016 ecsos@opensuse.org
- update to 1.2.4
  - reduced memory consumption of pitch detection process
  - Ported 1.2 branch to Mac Os
  BUGS FIXES
  - Fixed crash when note name tip was invoked from temporary,
    auto added note segment
  - Default color of enharmonic notes/names is set properly and
    approved when changed
  - Resizing issues - fingerboard never goes out of a view
  - other small fixes
* Sat Jan 16 2016 ecsos@opensuse.org
- update to 1.2.3
  BUGS FIXES
  - During exams - don't run pitch detection after settings dialog
    was closed
  - Fixed layout of exam results when note name is visible
  - Additional staff lines are hiding properly
  - Fixed conditions when 'correct' tool button is displayed
  - Questioned note and corrected one might have distorted
    colors - fixed
  - small fixes of translations
* Thu Oct  8 2015 ecsos@opensuse.org
- update to 1.2.2
  - updated Russian translation
  - added flick-able scroll (by mouse dragging) to windows with help
  BUGS FIXES
  - fixed crash related to hiding temp note segment at the staff end
  - properly loading translations of guitar tuning
  - fixed French translation
  - fixed mistakes in Polish translation
  - preventing of text selection in help windows
* Thu Sep  3 2015 ecsos@opensuse.org
- update to 1.2.1
  - fixed finger position validation - it might corrupt exam files
  - properly hide disabled double accidentals buttons in note name
    menu
  - fixed position of note name menu when it is moving between
    staves
  - fixed compilation issues if missing c++11 flag
* Sun Jul  5 2015 ecsos@opensuse.org
- update to 1.2.0
  - updated on-line help
  - unlocked help button(s) to opening related help sites
  - improved displaying accidentals and neutrals in melodies
  BUGS FIXES
  - repaired and improved asking penalty melodies in exams
  - fixed melody chart tip - correctly displays every attempt
    summary
  - fixed and improved animations of accidentals from note to key
    signature
  - intonation checking respects properly setting of accuracy level
  - fixed issue when exam was corrupted due to wrongly reading it
    from a file
  - fixed determining mistake types for melodies
  - fixed chart issues when melodies are analyzing
  - fixed a lot of small glitches
- changes from 1.1.7 rc2
  - improvements/fixes related to low latency and real-time audio
  - updated Qt libraries to the latest version in Windows installer
  - changed all static font sizes to system related sizes
  BUGS FIXES
  - proper clef rendering in question tips
  - proper re-sampling when rate is bigger than 48000
  - avoiding multiple calls of status messages for better
    performance
  - fixed loading Qt translations and switching languages
  - fixed Debian package dependencies, Ubuntu 14.04 is supported
    now
- changes from 1.1.6 rc1
  - new, advanced settings for pitch detection
  - workarounds to avoid pitch-detection of the same note twice
  - other pitch detection improvements
  - better support when audio input and output are different
    devices
  - updated translations
  BUGS FIXES
  - updated RtAudio to latest git version - many bugs fixes
  - tons of fixed bugs, mistakes and glitches...
- changes from 1.1.5 beta
  - detailed preview of melodies in charts
  - added new tool button with menu to manage a score
  - new, quick, click-less way for adding notes to a score
  - improved pop-up for selecting note name over score
  - a note from played exam melody can be selected to start playing
    from it
  - improved look of sound meters widgets
  - intonation accuracy can be set from intonation view
  - first run wizard comes back improved  - it is a plugin now
  - improved user visible texts
  - updated Windows installer
  BUGS FIXES
  - tons of fixed bugs, mistakes and glitches...
  Under the hood
  - external executable-s converted to plugins, loaded on demand
  - audio device has single instance shared with external settings
    plugin
- changes from 1.1.4 alpha
  - exam tips are storing their position when moved by user
  - some icons changed
  BUGS FIXES
  - fixed a lot of small glitches
  Under the hood
  - removed all 'extern' statements from libraries
- changes from 1.1.3 alpha
  - There is an option for using JACK (Linux) and ASIO (Windows)
  - pitch detection range is set dynamically instead of settings
  - two pitch detection methods merged into single, two-steps
    method
  - improved detection of quickly repeated (the same) notes
  - exam question tips are movable and were improved
  - window elements (hints, sound view, guitar, tool bar) can be
    hidden
  - dots marking frets are configurable
  BUGS FIXES
  - flickering of an analyze chart was put right
- changes from 1.1.2 alpha
  - exams/exercises support for playing melodies from a score
  - exams/exercises support for writing listened melodies
  - recognizing new mistake types related to melodies
  - added tuning fork button to play middle A in exams based on
    listening
  - added pop-up panes to quick manage a note in a score
  - improved randomization, all notes from range will occur equally
  - simple import/export melodies to XML (music) format
  Under the hood
  - binary format of exam files (*.noo) changed to text based
  - saving melodies and related information in *.noo files
  - dividing and cleaning monolithic code of examining process
- changes from 1.1.1 alpha
  - interactive score with staves (systems)
  - possibility of adding/removing notes to the score
  - GUI layout changed
  - option for displaying accidentals from key signature close
    to a note
  - note names can be displayed on the score (below every note)
  - option for forwarding audio input through selected audio output
  - improved level creator
  Under the hood
  - ported to Qt5
  - divided for libraries and external executable files
  - updated RtAudio version
  - updated SoundTouch version (Windows/MacOs), better optimization
  - under newer Windows Os-es version WASAPI or ASIO is used and
    DS for XP
  - merged audio input and output callback methods
  - ported binary format of *.nel files to XML
- changes from 1.0.1
  - finished German translation
  BUGS FIXES
  - fixed crash with some JACK configurations
  - small scaling issues in a chart
* Mon Mar 23 2015 ecsos@opensuse.org
- change source address
* Fri Mar 14 2014 edogawa@aon.at
- cleaned up filelist and buildrequires, moved changelog to nootka.changes
* Mon Feb 17 2014 See Look <seelook@gmail.com> 
- Update to version 1.0.0:
